@@ -13,10 +13,10 @@ def start(filename):
         prefix = filename.split('.')[1]
 
     if(prefix == 'py'):
-        compilePython(filename)
+        compileGeneric(filename, python_runner)
     elif(prefix == 'java'):
-        compileJava(filename)
+        compileGeneric(filename, java_runner)
     elif(prefix == 'js'):
-        compileNode(filename)
+        compileGeneric(filename, node_runner)
     else:
         print(colored(255, 216, 66, 'This File Type Is Not Supported.'))
